#ifndef NT2_INCLUDE_CONSTANTS_MONE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MONE_HPP_INCLUDED

#include <nt2/constant/include/constants/mone.hpp>

#endif
